.. highlight:: shell

============
Installation
============

At the command line::

    $ easy_install ufs_tools

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv ufs_tools
    $ pip install ufs_tools
